BleDiscoveryMode

Enum BleDiscoveryMode 

pub enum BleDiscoveryMode {
    Advertising,
    Connected,
    Any,
}
BLE discovery intent.

The bluest backend supports Connected and Any on all platforms. Advertising is not supported and will return an error.

Variants



Advertising

Discover devices currently advertising ZMK Studio BLE service data.



Connected

Discover devices already paired/connected in the OS BLE device store.



Any

Use the best available backend strategy for the current platform.